# libpythonpro
Módulo para exemplificar a construção de projetos Python no curso Pytools

Nesse curso é ensinado como contribuir com projetos de código aberto

Link para curso [Python Pro](https://plataforma.dev.pro.br/)

Suportada a versão 3 do Python

'''console
python3 -m venv .venv
source .venv/Scripts/activate
pip install -r requirements_dev.txt
'''
Para conferir a qualidade do código:
'''console 
flake8
'''


Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip